@@ -1,7 +1,10 @@
-from qtrf.units import prefix_map
+from qtrf.numeric_suffix import prefix_map
 
-units      = 'V'
+# prefixes
 prefix_map = prefix_map.copy()
 del(prefix_map['M'])
 del(prefix_map['G'])
 del(prefix_map['T'])
+
+# units
+units = 'V'
